[![Build Status](https://travis-ci.org/Yomguithereal/phylactery.svg)](https://travis-ci.org/Yomguithereal/phylactery)

# Phylactery

Curated collection of data structures for Python.

## Installation

You can install `phylactery` with pip with the following command:

```
pip install phylactery
```

## Usage

WIP...
